@@ -1,10 +1,10 @@
-from typing import Optional, Dict, Tuple
+from typing import Optional, Tuple
 from http.client import responses
 
 from requests import Request, Response
 
 
-class ScrapflyError(Exception):
+class ScrapflyError(BaseException):
     KIND_HTTP_BAD_RESPONSE = 'HTTP_BAD_RESPONSE'
     KIND_SCRAPFLY_ERROR = 'SCRAPFLY_ERROR'
 
@@ -60,13 +60,16 @@ class ScrapflyError(Exception):
         return message
 
 
-class EncoderError(Exception):
-    pass
+class EncoderError(BaseException):
+
+    def __init__(self, content:str):
+        self.content = content
+        super().__init__()
 
 
 class HttpError(ScrapflyError):
 
-    def __init__(self, request:Request, response:Response, **kwargs):
+    def __init__(self, request:Request, response:Optional[Response]=None, **kwargs):
         self.request = request
         self.response = response
         super().__init__(**kwargs)
@@ -237,3 +240,18 @@ class ErrorFactory:
                 return ErrorFactory.RESOURCE_TO_ERROR[resource](**args)
 
             return ScrapflyError(**args)
+
+__all__:Tuple[str, ...] = [
+    'ScrapflyError',
+    'ScrapflyAspError',
+    'ScrapflyProxyError',
+    'ScrapflyScheduleError',
+    'ScrapflyScrapeError',
+    'ScrapflySessionError',
+    'ScrapflyThrottleError',
+    'ScrapflyWebhookError',
+    'UpstreamHttpClientError',
+    'UpstreamHttpServerError',
+    'ApiHttpClientError',
+    'ApiHttpServerError'
+]
